==> haskell-lsp-types1.4-1.4.0.1-91-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-types
version:              1.4.0.1
visibility:           public
id:                   lsp-types-1.4.0.1-8CM7b74RUNb2LRDOfoJ9ni
key:                  lsp-types-1.4.0.1-8CM7b74RUNb2LRDOfoJ9ni
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  649aa6e6513e19b4a2453047338d2bb6
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap
    Language.LSP.VFS

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-types-1.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-types-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types1.4
hs-libraries:         HSlsp-types-1.4.0.1-8CM7b74RUNb2LRDOfoJ9ni
depends:
    Diff-0.4.1-GFCkXoW1sOmEQbYHDvlnNI
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0 binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9 deepseq-1.4.6.1
    directory-1.3.6.2 dlist-1.0-LNr75TD4CZoKEEzkBmhWjA filepath-1.4.2.2
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    hslogger-1.3.1.1-6ZXyyIUfBbTJX9w1e5IHfN
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0
    mod-0.2.0.1-AQHRY81UY789XuHU2wjU3u mtl-2.2.2
    network-uri-2.6.4.2-H8R7YZM4iJL108zVnRjrHh
    rope-utf16-splay-0.3.2.0-GY64AklgUIp5YxPTtgHB4l
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD
    some-1.0.5-L5glA67mR8RJufLDsA2lRz template-haskell-2.18.0.0
    temporary-1.3-92h1kCtCGR4FaQHxoGuxwh text-1.2.5.0
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-lsp-types1.4/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types1.4/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-types1.4-1.4.0.1-144.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.4.0.1
visibility:           public
id:                   lsp-types-1.4.0.1-60HT6Pjo02dKzvT8i4I1TZ
key:                  lsp-types-1.4.0.1-60HT6Pjo02dKzvT8i4I1TZ
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  d7eb2be220548b0fa647a014aae379a9
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap
    Language.LSP.VFS

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types1.4
hs-libraries:         HSlsp-types-1.4.0.1-60HT6Pjo02dKzvT8i4I1TZ
depends:
    Diff-0.4.1-Jc1TR9aaNUv129X0zlHNSG
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb filepath-1.4.2.2
    hashable-1.4.4.0-AT2Ub72SgpTFIbLYNtgVpj
    hslogger-1.3.1.2-BlZxG3iQQhoI8xSFe2q18V
    lens-5.2.3-7k2QwsHyLcVK6NgbwpIzej
    mod-0.2.0.1-Gi7RwD2JXKA3b0qHTJ6K7f mtl-2.2.2
    network-uri-2.6.4.2-6a0tnrWM371Ip5S0wD8Wxe
    rope-utf16-splay-0.4.0.0-HqC5dtfmkGA2zQNBrLgEco
    scientific-0.3.7.0-FVWP8DVCKbGBwiSARe0xui
    some-1.0.6-33UPTY2v022DFo5SyHLB0b template-haskell-2.19.0.0
    temporary-1.3-FG8be2uh4e8v7fVoGxla4 text-2.0.2
    unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C

haddock-interfaces:   /usr/share/doc/haskell-lsp-types1.4/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types1.4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
